import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import tost, {errorTost} from "kara-module-tost";
import 'kara-module-tost/lib/index.css'
import NickName from './nickName'
import Intro from './intro'
import HeadIcon from './headIcon'

@inject('UCInfoStore', 'ConfigStore')
@observer
class UCInfo extends Component {
  constructor(props) {
    super(props)
  }

  componentDidMount() {
    this.props.ConfigStore.config.httpAgent.get('/account/getCurrentAccountCard').then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          this.props.UCInfoStore.getUserCard(res)
        }
        else {
          tost({type: 'error', msg: '获取用户信息失败', time: 4})
        }
      }
    )
  }

  fomateDate = (strDate, type) => {
    if (!strDate) {
      if (type === 0) {
        return ' 月 日'
      }
      else {
        return '年 月 日'
      }
    }
    let da = new Date(strDate)
    let year = da.getFullYear() + '年'
    let month = (da.getMonth() + 1 < 10 ? '0' + (da.getMonth() + 1) : da.getMonth() + 1) + '月'
    let date = (da.getDate() < 10 ? '0' + (da.getDate()) : da.getDate() + 1) + '日'
    if (type === 0) {
      return [month, date].join('')
    }
    else {
      return [year, month, date].join('')
    }
  }

  render() {
    const {UCInfoStore, ConfigStore, lang} = this.props;
    const {karaui} = ConfigStore.config
    const {Scroll} = karaui
    if (ConfigStore === undefined || UCInfoStore === undefined) {
      return null
    }
    const {httpAgent} = ConfigStore.config
    const {updateNickName, updateSign} = UCInfoStore
    let user = ConfigStore.config.user

    if (!UCInfoStore.userCard) {
      return null;
    }
    return (
      <div className={css.UCInfo}>
        <Scroll>
          <HeadIcon headIcon={UCInfoStore.userCard.headIcon} user={user} lang={lang} httpAgent={httpAgent}
                    UCInfoStore={UCInfoStore}/>
          <div className={css.nickName}>
            <NickName lang={lang} nickName={UCInfoStore.userCard.nickName} httpAgent={httpAgent}
                      updateNickName={updateNickName}/>
            <Intro lang={lang} signature={UCInfoStore.userCard.signature} httpAgent={httpAgent}
                   updateSign={updateSign}/>
          </div>
          <div className={`clearfix ${css.workInfo}`}>
            <div><span className='s-hint'>NT</span><span>{user.staffAccount}</span></div>
            <div><span className='s-hint'>{lang.emId}</span><span>{user.staffCode}</span></div>
            <div><span className={`s-hint ${css.longWord}`}>{lang.email}</span><span>{user.email}</span></div>
            <div><span className='s-hint'>{lang.tel}</span><span>{user.phone}</span></div>
            <div><span className='s-hint'>{lang.phone}</span><span>{user.mobile}</span></div>
            <div><span className={`s-hint ${css.longWord}`}>BG</span><span>{user.bgId}</span></div>
            <div><span className='s-hint'>BU</span><span>{user.sbu}</span></div>
            <div><span className='s-hint'>{lang.company}</span><span>{user.companyName}</span></div>
            <div><span className={`s-hint ${css.longWord}`}>CC</span><span>{user.costCenterName}</span></div>
            <div><span className='s-hint'>{lang.department}</span><span>{user.orgName}</span></div>
            <div><span className='s-hint'>{lang.superior}</span><span>{user.parentStaffName}</span></div>
            <div><span className={`s-hint ${css.longWord}`}>{lang.workStation}</span><span>{user.officeAddr}</span>
            </div>
            <div className={css.full}><span
              className='s-hint'>{lang.label}</span><span>{user.tags === "" ? lang.noAbout : user.tags}</span></div>
          </div>
          <div className={css.brithday}>
            <div><span
              className='s-hint'>{lang.birthday}</span><span>{this.fomateDate(UCInfoStore.userCard.birthDay, 0)}</span><span>共{UCInfoStore.userCard.sameBirthDayCount}名同学与您同一天生日</span>
            </div>
            <div><span
              className='s-hint'>{lang.entryDate}</span><span>{this.fomateDate(UCInfoStore.userCard.hireDay, 1)}</span><span>您加入亚信大家庭已经{UCInfoStore.userCard.hireDayCount}天了，感谢您的辛苦付出</span>
            </div>
          </div>
        </Scroll>
      </div>
    )
  }
}

export default UCInfo
